$(document).ready(function(){
  
  //initiate tooltips
  $('[data-toggle="tooltip"]').tooltip();
  
  
  // ********************
  // SHOW Page
  // ********************
  
  // set SVG size
  var svg_width = $("#svg").width();
  var container_width = $("#text-viz").width();
  
  if (svg_width > container_width){
      $("#svg").width("100%");
      $("#svg").height("auto");
      $("#svg").toggle();
  }else{
      $("#svg").toggle();
  }
  
  // display SVG zoom control only for papyri width > 5 and height > 5 ?
  var controls = true;
  
  // initialize pan and zoom for SVG
  // only on pages with svg for papyri (otherwise messes up with back-to-top button)
  if($('#svg').length){
    var panZoomTiger = svgPanZoom('#svg', {
      controlIconsEnabled: true
    });  
  }

  
  // ********************
  // Recto/Verso
  // There is no fully consistent encoding in papyri.info
  // which creates some problems and prevent automatic processing
  // ******************** 
  
  // TM 219272: display columns that were hidden
  if ( $('idno').text() == '219272'){
      $('span[id*="abv"] + .textpart').show();
  }
  
  // TM 11695: hide the recto, we display the verso this time (removed from data)
  if ( $('idno').text() == '11965'){
      $('span[class="textpartnumber r"]').nextAll('.textpart').hide();
  }
  
  // TM 11697: hide the verso
  if ( $('idno').text() == '11967'){
      $('span[class="textpartnumber v"]').nextAll('.textpart').hide();
  }
  
  // TM 9196: hide the verso
  if ( $('idno').text() == '9196'){
      $('span[class="textpartnumber v"]').nextAll('.textpart').hide();
  }
  
  // TM 28932: we have both recto (28932b) and verso (28932b) as separate document
  // For 28932b, we need to display verso, hide recto
  if ( $('#filename').text() == '28932b.xml'){
      $('span[class="textpartnumber r"]').next('.textpart').hide();
      $('span[class="textpartnumber v"]').next('.textpart').show();
  }
  
  // ********************
  // margin text in vertical papyri
  // only known example so far are TM 905, 8621, 14917
  // ********************
  
  // style margin text to the left and to 25% width
  $("#abms, #abr\\,ms").next("div").css({
    "order": "-1", //place first
    "break-after": "right", // make separate columns (firefox)
    "width": "25%", 
    "word-wrap": "break-word"});
    
  // make separate columns (chrome) => messing up with firefox (cf. TM8621)
  //if (userAgentString.indexOf("Chrome") > -1) {
    //$("#abms, #abr\\,ms").closest("#edition").css({"flex-flow": "inherit"});
  //}  
   
  
  // style margin text to the right and to 25% width
  // TM 14917. This will probably not work well in multi-culumn documents
  $("#abmd, #abr\\,md").next("div").css({"order": "2", "page-break-before": "right", "width": "25%", "word-wrap": "break-word"});
  
  // style center text to 75% width
  //TEMPORARY: .ctr as class
  $(".ctr, .r\\,ctr").next().css({"width": "75%"});
  
  // style edition ancestor
  // TM905 needs 2 columns ms/ctr, but this is NOT WORKING IN CHROME
  if ( $('idno').text() == '905'){
    $("#abms").closest("#edition").css({"column-count": "2", "flex-flow": "column wrap"});
  }else{
    $("#abms").closest("#edition").css({}); 
  }
  
  // --------
  // add empty lines before the margin text
  // the number of lines depend on where in the papyrus the ms text begins
  // TM 905: starts at line 13, which is found in <a id="ms-l13">
  
  //ABMS
  // find the first element with an id in the margin text and select id value
  var line_attr = $("#abms").next().find("[id]:first").attr("id");
  if (typeof line_attr !== 'undefined'){
    var line_nb = line_attr.substr(line_attr.lastIndexOf("l") + 1);
  
    // add empty lines
    for (i = 0; i < line_nb-1; i++) {
      $("#abms").next("div").children("span").prepend("<br/>");
    }
  }
  
  // ABR,MS - TM 8621 special case.
  // margin text is not an annotation but the continuation of main text (scribe ran out of paper)
  // emtpy lines set by EN to 27, so that ctr and ms text are aligned at the bottom
  if ( $('idno').text() == '8621'){
    var line_nb_8621 = 27;
  
    // add empty lines
    for (i = 0; i < line_nb_8621-1; i++) {
      $("#abr\\,ms").next("div").children("span").prepend("<br/>");
    }
  }
  
  
  // ********************
  // double documents 
  // prevent ext/int text from being separated in columns
  // 
  // ********************
  
  // prevent column display
  $("#abr\\,int").closest("#edition").css({"display":"block"});
  
  // move interior script first
  $("#abr\\,int").next("div").prependTo("#edition");
  
  
  // ********************
  // iiif viewer
  //
  // ********************
  var manifest_link = $("#manifest").text();
  
  if(manifest_link){
      $(function() {
        Mirador({
          id: "mirador",
          data: [{ manifestUri: manifest_link, location: "My Repository"}],
          windowObjects: [{
              loadedManifest: manifest_link,
            //   canvasID: "http://iiif/id/and/uri/of/your/canvas/canvas-id",
              viewType: "ImageView"}]
        });
     });
  }
  
  
     
 // ********************
 // BROWSE Page
 // 
 // ********************
 
 // toggle facet header caret
 $(".facet-header > button").on('click', function(event) {
    $(this).children("i").toggleClass("fa-caret-up");
    $(this).children("i").toggleClass("fa-caret-down");
 });
 
 // back-to-top button
 $(window).scroll(function () {
			if ($(this).scrollTop() > 50) {
				$('#back-to-top').fadeIn();
			} else {
				$('#back-to-top').fadeOut();
			}
		});
		// scroll body to 0px on click
		$('#back-to-top').click(function () {
			$('body,html').animate({
				scrollTop: 0
			}, 400);
			return false;
		});
});